# NotifiableItem

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bcc** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**body** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**cc** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**default_option** | **str** |  | [optional] 
**format** | **str** |  | [optional] 
**methods** | **list[str]** |  | [optional] 
**reply_options** | **list[str]** |  | [optional] 
**subject** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**timings** | [**NotifyTimings**](NotifyTimings.md) |  | [optional] 
**to** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


